@@ -2,9 +2,8 @@ from .dot_parser import DOTParser
 from .file_factory import FastQFactory, FileFactory
 from .module import Module, modules, pipeline_names
 from .module_finder import ModuleFinder
-from .pipeline_manager import (PipelineManager, PipelineManagerDirectory,
-                               PipelineManagerGeneric)
-from .pipeline_utils import (Makefile, OnSuccess, OnSuccessCleaner,
+from .pipeline_manager import (PipelineManager, PipelineManagerDirectory)
+from .pipeline_utils import (Makefile, OnSuccessCleaner,
                              build_dynamic_rule, create_cleanup,
                              get_pipeline_statistics, message)
 from .sequana_config import SequanaConfig
